package org.jboss.tools.example.springmvc.domain;

import java.io.Serializable;
import java.util.List;

import javax.persistence.CascadeType;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.Inheritance;
import javax.persistence.InheritanceType;
import javax.persistence.JoinColumn;
import javax.persistence.OneToMany;
import javax.persistence.Table;
import javax.persistence.UniqueConstraint;
import javax.validation.constraints.Digits;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;

import org.hibernate.validator.constraints.Email;
import org.hibernate.validator.constraints.NotEmpty;

@Entity
@Inheritance(strategy=InheritanceType.JOINED)

@Table(uniqueConstraints = @UniqueConstraint(columnNames = "email"))
public class Member extends Person implements Serializable
{
   /** Default value included to remove warning. Remove or modify at will. **/
   private static final long serialVersionUID = 1L;
 
   
   @NotNull
   @NotEmpty
   @Email
   private String email;

   @NotNull
   @Size(min = 10, max = 12)
   @Digits(fraction = 0, integer = 12)
   @Column(name = "phone_number")
   private String phoneNumber;
   
   @OneToMany(cascade=CascadeType.ALL , mappedBy="member" , fetch=FetchType.EAGER)
   private List<UOrder> orders;
   
   public Member() {
	super();
	
   }
   
   @Override
   public String toString() {
	return "Member [email=" + email + ", phoneNumber=" + phoneNumber + ", orders=" + orders + "]";
   }
   
   public Member(String name, String email, String phoneNumber ,List<UOrder> orders) {
	   super(name);
	   this.orders = orders;
	   this.email = email;
	   this.phoneNumber = phoneNumber;
   }

   public String getEmail() {
      return email;
   }

   public void setEmail(String email) {
      this.email = email;
   }

   public String getPhoneNumber() {
      return phoneNumber;
   }

   public void setPhoneNumber(String phoneNumber) {
      this.phoneNumber = phoneNumber;
   }

	public List<UOrder> getOrders() {
		return orders;
	}
	
	public void setOrders(List<UOrder> orders) {
		this.orders = orders;
	} 
   
}